auth

package
v0.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 20, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Overview

Package auth provides commands for iTerm2 API authentication.

Authentication is required to access iTerm2's WebSocket API. This package provides commands to:

  • request: Request authentication from iTerm2 (interactive)
  • check: Verify current authentication status

The authentication process involves iTerm2 generating a cookie and key pair that must be provided with API requests. These credentials are typically stored in environment variables for subsequent use.

Examples:

it2 auth request
it2 auth check

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewCommand

func NewCommand() *cobra.Command

NewCommand creates the auth command with all subcommands.

Types

This section is empty.

Jump to