plugins

package
v0.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 20, 2026 License: MIT Imports: 11 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewClaudeCodeHookCommand

func NewClaudeCodeHookCommand(meta plugins.PluginMetadata) *cobra.Command

NewClaudeCodeHookCommand creates a special command for claude-code-hook with --install flag. Exported so that the deprecated tool command can delegate to this implementation.

func NewCommand

func NewCommand() *cobra.Command

NewCommand creates the plugin command with all subcommands. This is the primary command for managing and running plugins. Plugin discovery is deferred until the "run" subcommand is invoked, avoiding expensive PATH scanning at CLI startup.

Types

This section is empty.

Jump to