tool

package
v0.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 20, 2026 License: MIT Imports: 7 Imported by: 0

Documentation

Overview

Package tool provides direct access to built-in session plugins.

The tool command exposes all discovered plugins as subcommands, allowing them to be invoked directly via the CLI.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewCommand

func NewCommand() *cobra.Command

NewCommand creates the tool command with dynamically generated subcommands for each plugin.

Types

This section is empty.

Jump to