utility

package
v0.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 20, 2026 License: MIT Imports: 10 Imported by: 0

Documentation

Overview

Package utility provides iTerm2 utility and helper commands.

Utility commands provide access to various iTerm2 convenience features such as cursor guides, timestamps, shell integration installation, and integration with external tools like password managers and SSH.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewCommand

func NewCommand() *cobra.Command

NewCommand creates the utility command with all subcommands.

Types

This section is empty.

Jump to