Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ExtractPlugins ¶
ExtractPlugins extracts embedded plugins to ~/.it2/plugins/{build-hash} Returns the directory path where plugins were extracted
func GetPluginsDir ¶
GetPluginsDir returns the path where embedded plugins should be extracted Uses build hash to ensure plugins match the binary version
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.