Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func MapKeyToCode ¶
MapKeyToCode maps special key names to their corresponding character codes or escape sequences. Returns empty string if the key is not a special key (should be used as-is).
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.