Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AuthDisabled ¶
func AuthDisabled() bool
AuthDisabled checks if authentication is disabled via the special file This follows the same mechanism as the Python iTerm2 API
func CheckAutomationEnabled ¶
func CheckAutomationEnabled() error
CheckAutomationEnabled checks if iTerm2 automation is properly enabled Returns nil if enabled, or an error with helpful instructions if not
func ClearAuthentication ¶
func ClearAuthentication()
ClearAuthentication removes authentication credentials from environment
func DisableAutomation ¶
func DisableAutomation() error
DisableAutomation disables iTerm2 API automation by setting EnableAPIServer to false
func EnableAutomation ¶
func EnableAutomation() error
EnableAutomation enables iTerm2 API automation by setting EnableAPIServer to true
func HasAuthentication ¶
func HasAuthentication() bool
HasAuthentication checks if authentication credentials are present
func RequestAuthentication ¶
func RequestAuthentication() error
RequestAuthentication requests cookie and key from iTerm2 via AppleScript
Types ¶
type AutomationNotEnabledError ¶
type AutomationNotEnabledError struct{}
AutomationNotEnabledError represents the error when iTerm2 automation is not enabled
func (*AutomationNotEnabledError) Error ¶
func (e *AutomationNotEnabledError) Error() string