Documentation
¶
Overview ¶
Package tool provides direct access to built-in session plugins.
The tool command exposes all discovered plugins as subcommands, allowing them to be invoked directly via the CLI.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewCommand ¶
NewCommand creates the tool command with dynamically generated subcommands for each plugin.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.