Documentation
¶
Overview ¶
Package utility provides iTerm2 utility and helper commands.
Utility commands provide access to various iTerm2 convenience features such as cursor guides, timestamps, shell integration installation, and integration with external tools like password managers and SSH.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewCommand ¶
NewCommand creates the utility command with all subcommands.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.