utils

package
v0.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 20, 2026 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func MapKeyToCode

func MapKeyToCode(key string) string

MapKeyToCode maps special key names to their corresponding character codes or escape sequences. Returns empty string if the key is not a special key (should be used as-is).

Types

This section is empty.

Jump to